/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
#ifndef CONFIGVIEW_H
#define CONFIGVIEW_H

class ModuleManager;

/**
 * @class ConfigView
 * @brief The base class for all config views.
 *
 * A config view is a graphical representation of the settings.  More precisely, 
 * a view is a window.  This base class sets a common interface to allow the
 * creation of many different views base on different toolkits.
 * The config views are used in sofa-config.
 */
class ConfigView {
  // Associations
  // Attributes
  // Operations
  public:
  
    /**
     * @brief Initialise the underlying toolkit.
     * @param argc The argument count passed to main().
     * @param argv The argument vector passed to main().
     */
    virtual void init ( int argc, char* argv[] ) = 0;
    
    /**
     * @brief Opens the window.
     * 
     * This call should be blocking.  When the window is closed, this method will
     * return.
     */
    virtual void show (  ) = 0;
    
    /**
     * @brief Sets a reference to the Module list.
     * @param manager The ModuleManager created in main()
     */
     virtual void setModuleManager(ModuleManager * manager) = 0;
};

#endif
