/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <config.h>
#include <stdio.h>

#include "../debug.h"
#include "../sofa-i18n.h"
#include "gtkconfigview.h"
#include "../modules/modulemanager.h"
#include "../settings.h"

static gboolean debugOption = FALSE;

static GOptionEntry options[] = 
{
  { "debug", 'd', 0, G_OPTION_ARG_NONE, &debugOption, _("Turns on debug messages"), NULL },
  
  { NULL }
};

int
main (int argc, char *argv[])
{
  setlocale (LC_ALL, "");
  bindtextdomain (GETTEXT_PACKAGE, SOFALOCALEDIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
  textdomain (GETTEXT_PACKAGE);  
  
// Parse commande line options
  GError *error = NULL;
  GOptionContext *context;

  context = g_option_context_new (_("Allow configuration of Sofa Media Center"));
  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
  g_option_context_parse (context, &argc, &argv, &error);
  setDebug(debugOption);
  
  g_print("%s\n", PACKAGE_STRING);
  g_print(_("Copyright (c) 2007 Pierre-Luc Beaudoin\n"));
  g_print(_("This is free software.  You may redistribute copies of it under the terms of\n\
the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.\n\
There is NO WARRANTY, to the extent permitted by law.\n\n"));
  
  // Initialise the application
  SETTINGS->init(argc, argv);
  
  ModuleManager manager;
  manager.loadModules(false);
  
  GtkConfigView sofaConfig;
  sofaConfig.init(argc, argv);
  sofaConfig.setModuleManager(&manager);
  
  // Starts the show
  sofaConfig.show();
  
  //Unload modules
	return 0;
}


