/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include "mediamenu.h"
#include "playerstate.h"
#include "playingstate.h"
#include "../../clip.h"
#include "../../views/playlist.h"

#include <assert.h>

gboolean
controls_timeout_cb (MediaMenu * data)
{
  data->controlsOff();
  return FALSE;
}

MediaMenu::MediaMenu(){
  _playlist = NULL;
  _controls_to = 0;
  _controls_on = false;
}

void MediaMenu::doAction (Actions anAction){
  switch(anAction){
    case Menu::MENU: 
      _state->doEvent(PlayerState::PAUSE);
      unselect();
      getParent()->select();
      break;
    case Menu::LEFT: 
    case Menu::UP: 
    case Menu::RIGHT: 
    case Menu::DOWN:
    case Menu::OK: 
      PlayerState::Events anEvent = _state->getCurrentState()->getEventFromAction(anAction);
      _state->getCurrentState()->doEvent(anEvent);
      break;
  }
  controlsOn();
  
}

void MediaMenu::setMediaPlayer ( MediaPlayer * mp ){
  
  _mediaPlayer = mp;
  mp->signal_tick.connect( sigc::mem_fun( this, &MediaMenu::tick) ) ; 
  
}

void MediaMenu::play (Playlist * playlist ){
  _playlist = playlist;
  playlist->signal_currentChanged.connect( sigc::mem_fun( this, &MediaMenu::currentChanged) ) ; 
  _state = PlayerState::getInitialState();
  _state->init(_mediaPlayer, playlist);
  _state->enter();
  
  controlsOn();
}

MediaPlayer * MediaMenu::getMediaPlayer ( ){
  return _mediaPlayer;
}

Clip * MediaMenu::getCurrentClip(){
  if(_playlist)
    return _playlist->getCurrentClip();
  else
    assert(!"Playlist should'nt be null");
}

void MediaMenu::tick ( ){
  //when the player ticks, the view needs to be updated
  signal_changed(Menu::TICK);
}

void MediaMenu::currentChanged ( ){
  //when the playlist is done, leave this menu
  signal_changed(Menu::PROPERTIES_CHANGED);
}

void MediaMenu::controlsOn ( ){
  
  if(!(_controls_to == 0))
    g_source_remove(_controls_to);
  else
    signal_changed(Menu::CONTROLS_ON);
    
  _controls_to = g_timeout_add (
        5 * 1000,  
        (GSourceFunc)controls_timeout_cb,
        this
        );
     
}

void MediaMenu::controlsOff ( ){
  _controls_to = 0;
  signal_changed(Menu::CONTROLS_OFF);
}
