/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
#include "pausedstate.h"
#include "playingstate.h"
#include "../../views/playlist.h"

PlayerState::Events PausedState::getEventFromAction ( Menu::Actions action ){
  switch(action){
    case Menu::LEFT: 
      return PlayerState::PREVIOUS;
      break;
    case Menu::UP: 
      return PlayerState::VOLUME_UP;
      break;
    case Menu::RIGHT: 
      return PlayerState::NEXT;
      break;
    case Menu::DOWN:
      return PlayerState::VOLUME_DOWN;
      break;
    case Menu::OK: 
      printf("In Paused: OK == PLAY\n");
      return PlayerState::PLAY;
      break;
  }
}

PlayerState *PausedState::getNextState ( PlayerState::Events event ){
   switch(event){
    case PlayerState::PLAY:
      return _playingState;
      break;
    case PlayerState::PAUSE:
      return _pausedState;
      break;
  }
  return this;
}

void PausedState::enter (  ){
  printf("paused::enter()\n");
  _currentState = this;
  _mediaPlayer->pause();
}

void PausedState::force (  ){
  //Check if not the end of a song, then next in playlist
  //if end of playlist then emit signal_end
  if(_mediaPlayer->getProgress() == 1)
    next();
  printf("paused::force()\n");
  _currentState = this;
}

void PausedState::doEvent ( PlayerState::Events event ){
  switch(event){
    case PlayerState::NEXT:
      next();
      break;
    case PlayerState::PREVIOUS:
      previous();
      break;
    case PlayerState::VOLUME_UP:
      _mediaPlayer->setVolume( 
        _mediaPlayer->getVolume() + 0.2
        );
      break;
    case PlayerState::VOLUME_DOWN:
      _mediaPlayer->setVolume( 
        _mediaPlayer->getVolume() - 0.2
        );
      break;
    default:
      PlayerState::doEvent( event );
      break;
      
  }
}

void PausedState::next(){
  _playlist->next();
}

void PausedState::previous(){
  _playlist->previous();
}
