/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "playerstate.h"
#include "playingstate.h"
#include "pausedstate.h"
#include "loadingstate.h"
#include "../../views/playlist.h"
#include "../../clip.h"

#include <assert.h>
// As per http://weblogs.asp.net/whaggard/archive/2004/11/05/252685.aspx
// Static members needs to be declared outside of classes!

PlayingState  * PlayerState::_playingState = new PlayingState();
PlayerState   * PlayerState::_currentState = PlayerState::_playingState;
PausedState   * PlayerState::_pausedState  = new PausedState();
LoadingState  * PlayerState::_loadingState = new LoadingState();
MediaPlayer   * PlayerState::_mediaPlayer  = NULL;
Playlist      * PlayerState::_playlist     = NULL;
    
PlayerState::PlayerState() {
  
}

void PlayerState::init (MediaPlayer * mp,  Playlist * playlist ){
  _mediaPlayer = mp;
  mp->signal_playing.connect(sigc::mem_fun(*_playingState, &PlayingState::force));
  mp->signal_paused.connect(sigc::mem_fun(*_pausedState, &PausedState::force));
  
  _currentState = _playingState; 
  
  _playlist = playlist;
  _mediaPlayer->setURI(_playlist->getCurrentClip()->getURI().c_str());
  
}

bool PlayerState::isPlaying (  ){
  return (_currentState == dynamic_cast<PlayerState*>(_playingState));
}

bool PlayerState::isPaused (  ){
  return (_currentState == dynamic_cast<PlayerState*>(_pausedState));
}

bool PlayerState::isLoading (  ){
  return (_currentState == dynamic_cast<PlayerState*>(_loadingState));
}

void PlayerState::doEvent ( PlayerState::Events event ){
  PlayerState * st = _currentState->getNextState(event);
  if(st)
    st->enter();
}

PlayerState * PlayerState::getInitialState(){
  return _playingState;
}

PlayerState * PlayerState::getCurrentState(){
  return _currentState;
}
