/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "../../sofa-i18n.h"
#include "../../menus/viewers/musicmenu.h"
#include "rhythmboxmodule.h"
#include "rhythmboxconfigwindow.h"
#include "rbmediaplayer.h"
#include "rbplaylist.h"

#include <assert.h>

RhythmboxModule::RhythmboxModule(){
  _root = NULL;
}

const gchar * RhythmboxModule::getName (  ){
  return _("Rhythmbox");
}

const gchar * RhythmboxModule::getSettingName (  ){
  return "rhythmbox";
}

const gchar * RhythmboxModule::getVersion (  ){
  return "0.1.1";
}

const gchar * RhythmboxModule::getAuthor (  ){
  return "Pierre-Luc Beaudoin";
}

const gchar * RhythmboxModule::getDescription (  ){
  return _("This module allows remote control of Rhythmbox");
}

void RhythmboxModule::unload (  ){
  assert(!"Unimplemented");
}

Menu* RhythmboxModule::getMenu (  ){
  if(!_root){
     _root = new MusicMenu();
  
    _root->setTitle(_("Rhythmbox..."));
    _root->setSubtitle(_("Current song in Rhythmbox"));
    _root->setImagePath("/usr/share/icons/Tango/scalable/devices/multimedia-player.svg");
    _root->signal_load.connect(sigc::mem_fun(this, &RhythmboxModule::loadSubMenu));
  }
  return _root;
}
    
void RhythmboxModule::loadSubMenu(){
  
  MusicMenu * list = reinterpret_cast<MusicMenu *>(_root);
  MediaPlayer *mp = new RBMediaPlayer();
  mp->init(0, NULL);
  list->setMediaPlayer(mp);

  list->setPercentLoaded(0.1);

  RBPlaylist * pl = new RBPlaylist();
  pl->init(0, NULL, mp);
  list->play(pl);
  list->setPercentLoaded(1.0);
  
}

ConfigWindow * RhythmboxModule::getConfigWindow (  ) {
  RhythmboxConfigWindow * ret = new RhythmboxConfigWindow();
  return ret;
}
