/* 
 * Copyright (C) 2007 Pierre-Luc Beaudoin
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either 
 * version 2 of the License, or (at your option) any later 
 * version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
#include "settings.h"
#include "debug.h"
#include <assert.h>
#include <gconf/gconf-client.h>


Settings* Settings::getInstance (  ){
  static Settings * _instance = NULL;
  if(_instance == NULL)
    _instance = new Settings();
  
  return _instance;
}
void Settings::init (  int argc, char * argv[]  ){
  log("Initializing Settings");
  gconf_init(argc, argv, NULL);
  _client = gconf_client_get_default();
  log("Initializing Settings - Done");
}

bool Settings::getBool (const gchar * setting ){
  log("Retrieving key %s", setting);
  return gconf_client_get_bool(_client, setting, NULL);
}

int Settings::getInt (const gchar * setting ){
  log("Retrieving key %s", setting);
  return gconf_client_get_int(_client, setting, NULL);
}

gchar * Settings::getString (const gchar * setting ){
  log("Retrieving key %s", setting);
  return gconf_client_get_string(_client, setting, NULL);
}

gchar * Settings::getStringList ( const gchar * setting, int pos ){
  log("Retrieving key %s", setting);
  GSList * tmp = gconf_client_get_list( _client, 
    setting, 
    GCONF_VALUE_STRING, 
    NULL
    );
  if(tmp)
    return reinterpret_cast<gchar*>(g_slist_nth(tmp, pos)->data);
  else 
    return "t";
}

int Settings::getStringListSize ( const gchar * setting ){
  log("Retrieving key %s", setting);
  GSList * tmp = gconf_client_get_list( _client, 
    setting, 
    GCONF_VALUE_STRING, 
    NULL
    );
  if(tmp)
    return g_slist_length(tmp);
  else
    return 0;
}

void Settings::setBool ( const gchar * setting, bool value ){
  gconf_client_set_bool(_client, setting, value, NULL);
}

void Settings::setInt ( const gchar * setting, int value ){
  gconf_client_set_int(_client, setting, value, NULL);
}

void Settings::setString ( const gchar * setting, const gchar * value ){
  gconf_client_set_string(_client, setting, value, NULL);
}

gchar * Settings::setStringList ( const gchar * setting, gchar * * value, int size ){
  GSList * tmp = NULL;
  for(int i = 0; i < size; i++){
    tmp = g_slist_append(tmp,(void*) value[i]);
  }
 
  gconf_client_set_list(_client, setting, GCONF_VALUE_STRING, tmp, NULL);
  
}

